Changelog
=========

1.1 (2013-08-07)
----------------

* Reduce resources size feature `Issue #6 <https://github.com/SolutionsCloud/apidoc/issues/6>`_
* DiffMode on small devices feature `Issue #8 <https://github.com/SolutionsCloud/apidoc/issues/8>`_
* Link to the top feature `Issue #9 <https://github.com/SolutionsCloud/apidoc/issues/9>`_
* The keyword optional override code bug `Issue #10 <https://github.com/SolutionsCloud/apidoc/issues/10>`_
* Inprove detected types feature `Issue #11 <https://github.com/SolutionsCloud/apidoc/issues/11>`_
* Add rules on properties feature `Issue #12 <https://github.com/SolutionsCloud/apidoc/issues/12>`_
* Add PATCH and OPTION method feature `Issue #13 <https://github.com/SolutionsCloud/apidoc/issues/13>`_
* Replace shortcup popin by bootstrap modal `Issue #14 <https://github.com/SolutionsCloud/apidoc/issues/14>`_

1.0 (2013-07-23)
----------------

* Initial release